@@ -1,4 +1,3 @@
-import sys
 import unittest
 
 from supervisor.tests.base import DummyOptions
@@ -508,10 +507,3 @@ class TestUtilityFunctions(unittest.TestCase):
             self.assertTrue(events.EventTypes.FOO is FooEvent)
         finally:
             del events.EventTypes.FOO
-
-def test_suite():
-    return unittest.findTestCases(sys.modules[__name__])
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
-
